# readcomiconline.to downloader

A readcomiconline.to downloader using asyncio.

## Dependencies

* Node.js: Used by cfscrape to bypass CloudFlare's antibot.

## Usage

`rco_dl <url_to_comic>` will download the HQ images of the comic to a cbz file on the directory where the script is located.
